@@ -53,6 +53,7 @@ class SnowflakeDataSource(DataSource):
         super().__init__(logs, data_source_name, data_source_properties)
         self.user = data_source_properties.get("username")
         self.password = data_source_properties.get("password")
+        self.token = data_source_properties.get("token")
         self.account = data_source_properties.get("account")
         self.data_source = data_source_properties.get("data_source")
         self.warehouse = data_source_properties.get("warehouse")
@@ -74,6 +75,7 @@ class SnowflakeDataSource(DataSource):
         self.connection = connector.connect(
             user=self.user,
             password=self.password,
+            token=self.token,
             account=self.account,
             data_source=self.data_source,
             database=self.database,
@@ -119,6 +121,18 @@ class SnowflakeDataSource(DataSource):
     def regex_replace_flags(self) -> str:
         return ""
 
+    def expr_regexp_like(self, expr: str, pattern: str):
+        return f"REGEXP_LIKE(COLLATE({expr}, ''), '{pattern}')"
+
+    def cast_text_to_number(self, column_name, validity_format: str):
+        """Cast string to number
+        - first regex replace removes extra chars, keeps: "digits + - . ,"
+        - second regex changes "," to "."
+        - Nullif makes sure that if regexes return empty string then Null is returned instead
+        """
+        regex = self.escape_regex(r"'[^-0-9\.\,]'")
+        return f"CAST(NULLIF(REGEXP_REPLACE(REGEXP_REPLACE(COLLATE({column_name}, ''), {regex}, ''{self.regex_replace_flags()}), ',', '.'{self.regex_replace_flags()}), '') AS {self.SQL_TYPE_FOR_CREATE_TABLE_MAP[DataType.DECIMAL]})"
+
     def get_metric_sql_aggregation_expression(self, metric_name: str, metric_args: list[object] | None, expr: str):
         # TODO add all of these snowflake specific statistical aggregate functions: https://docs.snowflake.com/en/sql-reference/functions-aggregation.html
         if metric_name in [
@@ -165,8 +179,3 @@ class SnowflakeDataSource(DataSource):
             self.type,
             self.account,
         ]
-
-    def create_test_table_manager(self):
-        from tests.snowflake_data_source_fixture import SnowflakeDataSourceFixture
-
-        return SnowflakeDataSourceFixture(self)
